@@ -65,7 +65,8 @@ def zinc_drug(genes_list:list, zinc_type:str = 'all', species:str = 'all'):
                 if True not in np.unique(df.columns == 'gene_name'):
                     df['gene_name'] = gen
                 df_zinc = pd.concat([df_zinc, df], axis=0)
-    
+                
+    df_zinc['ortholog_name'][pd.isnull(df_zinc['ortholog_name'])] = 'NaN'
     df_zinc['species'] = [re.sub('.*_', '', i) for i in df_zinc['ortholog_name']]
     
     if species == 'hs':
@@ -80,8 +81,8 @@ def zinc_plot(res_zinc:pd.DataFrame, p_val, adj:str = 'None', dir:str = 'results
 
     adj = adj.upper()
     
-    if not os.path.exists('results'):
-        os.mkdir('results')
+    if not os.path.exists(dir):
+        os.makedirs(dir)
 
     df3 = res_zinc[['zinc_id', 'gene_name']]
     df3 = df3.drop_duplicates()
